﻿Imports System.Net
Imports System.Windows
Imports System.Windows.Controls
Imports System.Windows.Documents
Imports System.Windows.Input
Imports System.Windows.Media
Imports System.Windows.Media.Animation
Imports System.Windows.Navigation
Imports System.Windows.Shapes
Imports Microsoft.Phone.Controls
Imports Microsoft.Phone.Shell
Imports System.Diagnostics

Partial Public Class App
    Inherits Application
    Private Shared _viewModel As MainViewModel = Nothing

    ''' <summary>
    ''' バインドするビューで使用される静的 ViewModel です。
    ''' </summary>
    ''' <returns>MainViewModel オブジェクトです。</returns>
    Public Shared ReadOnly Property ViewModel() As MainViewModel
        Get
            ' 必要になるまでビュー モデルの作成を延期します
            If _viewModel Is Nothing Then
                _viewModel = New MainViewModel()
            End If

            Return _viewModel
        End Get
    End Property

    ''' <summary>
    ''' Phone アプリケーションのルート フレームへの容易なアクセスを提供します。
    ''' </summary>
    ''' <returns>Phone アプリケーションのルート フレームです。</returns>
    Public Property RootFrame() As PhoneApplicationFrame

    ''' <summary>
    ''' Application オブジェクトのコンストラクターです。
    ''' </summary>
    Public Sub New()
        ' Silverlight の標準初期化
        InitializeComponent()

        ' Phone 固有の初期化
        InitializePhoneApplication()

        ' デバッグ中にグラフィックスのプロファイル情報を表示します。
        If System.Diagnostics.Debugger.IsAttached Then
            ' 現在のフレーム レート カウンターを表示します。
            Application.Current.Host.Settings.EnableFrameRateCounter = True

            ' 各フレームで再描画されているアプリケーションの領域を表示します。
            'Application.Current.Host.Settings.EnableRedrawRegions = True

            ' 試験的な分析視覚化モードを有効にします。 
            ' これにより、色付きのオーバーレイを使用して、GPU に渡されるページの領域が表示されます。
            'Application.Current.Host.Settings.EnableCacheVisualization = True


            ' アプリケーションの PhoneApplicationService オブジェクトの UserIdleDetectionMode プロパティを Disabled に設定して、
            ' アプリケーションのアイドル状態の検出を無効にします。
            ' 注意: これはデバッグ モードのみで使用してください。ユーザーが電話を使用していないときに、ユーザーのアイドル状態の検出を無効にする
            ' アプリケーションが引き続き実行され、バッテリ電源が消耗します。
            PhoneApplicationService.Current.UserIdleDetectionMode = IdleDetectionMode.Disabled
        End If

    End Sub

    ' (たとえば、[スタート] メニューから) アプリケーションが起動するときに実行されるコード
    ' このコードは、アプリケーションが再アクティブ化済みの場合には実行されません
    Private Sub Application_Launching(ByVal sender As Object, ByVal e As LaunchingEventArgs)
    End Sub

    ' アプリケーションがアクティブになった (前面に表示された) ときに実行されるコード
    ' このコードは、アプリケーションの初回起動時には実行されません
    Private Sub Application_Activated(ByVal sender As Object, ByVal e As ActivatedEventArgs)
        ' アプリケーションの状態が適切に復元されたことを確認します
        If Not App.ViewModel.IsDataLoaded Then
            App.ViewModel.LoadData()
        End If
    End Sub

    ' アプリケーションが非アクティブになった (バックグラウンドに送信された) ときに実行されるコード
    ' このコードは、アプリケーションの終了時には実行されません
    Private Sub Application_Deactivated(ByVal sender As Object, ByVal e As DeactivatedEventArgs)
    End Sub

    ' (たとえば、ユーザーが戻るボタンを押して) アプリケーションが終了するときに実行されるコード
    ' このコードは、アプリケーションが非アクティブになっているときには実行されません
    Private Sub Application_Closing(ByVal sender As Object, ByVal e As ClosingEventArgs)
        ' 必要なアプリケーションの状態が持続していることをここで確認します。
    End Sub

    ' ナビゲーションに失敗した場合に実行されるコード
    Private Sub RootFrame_NavigationFailed(ByVal sender As Object, ByVal e As NavigationFailedEventArgs)
        If Debugger.IsAttached Then
            ' ナビゲーションに失敗しました。デバッガーで中断します。
            Debugger.Break()
        End If
    End Sub

    ' ハンドルされない例外の発生時に実行されるコード
    Private Sub Application_UnhandledException(ByVal sender As Object, ByVal e As ApplicationUnhandledExceptionEventArgs) Handles Me.UnhandledException
        If Debugger.IsAttached Then
            ' ハンドルされない例外が発生しました。デバッガーで中断します。
            Debugger.Break()
        End If
    End Sub

#Region "Phone アプリケーションの初期化"

    ' 初期化の重複を回避します
    Private phoneApplicationInitialized As Boolean = False

    ' このメソッドに新たなコードを追加しないでください
    Private Sub InitializePhoneApplication()
        If phoneApplicationInitialized Then
            Return
        End If

        ' フレームを作成しますが、まだ RootVisual に設定しないでください。これによって、アプリケーションがレンダリングできる状態になるまで、
        ' スプラッシュ スクリーンをアクティブなままにすることができます。
        RootFrame = New PhoneApplicationFrame()
        AddHandler RootFrame.Navigated, AddressOf CompleteInitializePhoneApplication

        ' ナビゲーション エラーを処理します
        AddHandler RootFrame.NavigationFailed, AddressOf RootFrame_NavigationFailed

        ' 再初期化しないようにします
        phoneApplicationInitialized = True
    End Sub

    ' このメソッドに新たなコードを追加しないでください
    Private Sub CompleteInitializePhoneApplication(ByVal sender As Object, ByVal e As NavigationEventArgs)
        ' ルート visual を設定してアプリケーションをレンダリングできるようにします
        If RootVisual IsNot RootFrame Then
            RootVisual = RootFrame
        End If

        ' このハンドラーは必要なくなったため、削除します
        RemoveHandler RootFrame.Navigated, AddressOf CompleteInitializePhoneApplication
    End Sub

#End Region
End Class